import {//importing libraries
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis
} from 'd3';

const svg = select('svg');
//defining width and height for plot
const width = +svg.attr('width');
const height = +svg.attr('height');
//defining X-axis and Y axis
const render = data => {
  const xValue = d => d.year;
  const xAxisLabel = 'year';
  //labeling and defining Y-axis
  
  const yValue = d => d.avg_age;
  const yAxisLabel = 'avg_age';
  //applying styles for plot
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0,innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight,0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -70)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 50)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  //line graph genertor
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
 	  .curve(curveBasis);
  
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', lineGenerator(data));
  //appending text to title
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};
//loading the data
csv('https://gist.githubusercontent.com/sushmachirra/8a10450cc2621dac9c476f8498d58cf3/raw/565221a9ee26b843994f1ad825f46e58f8b33bfe/age.csv')
  .then(data => {
    data.forEach(d => {
      d.avg_age = +d.avg_age;
      d.year = +d.year;
    });
    render(data);
  });